Security Advisories (2)
CVE-2016-1238 (2016-08-02)

Imager would search the default current directory entry in @INC when searching for file format support modules.

CVE-2024-53901 (2024-11-17)

"invalid next size" backtrace on use of trim on certain images

NAME

Imager::Color::Table - built-in Imager color table

SYNOPSIS

use Imager::Color::Table;
my @rgb = Imager::Color::Table->get($name)
  or die "Color $name not found";

DESCRIPTION

This class provides a base color table for use in resolving color names.

The table contains the standard X11 rgb.txt colors.

This table is not included as part of Imager::Color itself since it's moderately large.

There is only one method:

get
my @rgb = Imager::Color::Table->get('red')
  or die "No red found";

Retrieves a color from Imager::Color::Tables built-in color table.

AUTHOR

Tony Cook <tony@develop-help.com>